import pdfjs from '@bundled-es-modules/pdfjs-dist';
import React, { useRef, useEffect, useState, useMemo } from 'react';

var Pdf = function Pdf(_ref) {
  var file = _ref.file,
      onDocumentComplete = _ref.onDocumentComplete,
      page = _ref.page,
      scale = _ref.scale,
      rotate = _ref.rotate,
      cMapUrl = _ref.cMapUrl,
      cMapPacked = _ref.cMapPacked,
      workerSrc = _ref.workerSrc,
      withCredentials = _ref.withCredentials;
  var canvasEl = useRef(null);

  var _usePdf = usePdf({
    canvasEl: canvasEl,
    file: file,
    page: page,
    scale: scale,
    rotate: rotate,
    cMapUrl: cMapUrl,
    cMapPacked: cMapPacked,
    workerSrc: workerSrc,
    withCredentials: withCredentials
  }),
      numPages = _usePdf[1];

  useEffect(function () {
    onDocumentComplete(numPages);
  }, [numPages]);
  return React.createElement("canvas", {
    ref: canvasEl
  });
};

Pdf.defaultProps = {
  onDocumentComplete: function onDocumentComplete() {}
};
var usePdf = function usePdf(_ref2) {
  var canvasEl = _ref2.canvasEl,
      file = _ref2.file,
      _ref2$scale = _ref2.scale,
      scale = _ref2$scale === void 0 ? 1 : _ref2$scale,
      _ref2$rotate = _ref2.rotate,
      rotate = _ref2$rotate === void 0 ? 0 : _ref2$rotate,
      _ref2$page = _ref2.page,
      page = _ref2$page === void 0 ? 1 : _ref2$page,
      cMapUrl = _ref2.cMapUrl,
      cMapPacked = _ref2.cMapPacked,
      _ref2$workerSrc = _ref2.workerSrc,
      workerSrc = _ref2$workerSrc === void 0 ? '//cdnjs.cloudflare.com/ajax/libs/pdf.js/2.2.228/pdf.worker.js' : _ref2$workerSrc,
      _ref2$withCredentials = _ref2.withCredentials,
      withCredentials = _ref2$withCredentials === void 0 ? false : _ref2$withCredentials;

  var _useState = useState(),
      pdf = _useState[0],
      setPdf = _useState[1];

  useEffect(function () {
    pdfjs.GlobalWorkerOptions.workerSrc = workerSrc;
  }, []);
  useEffect(function () {
    var config = {
      url: file,
      withCredentials: withCredentials
    };

    if (cMapUrl) {
      config.cMapUrl = cMapUrl;
      config.cMapPacked = cMapPacked;
    }

    pdfjs.getDocument(config).promise.then(setPdf);
  }, [file, withCredentials]); // handle changes

  useEffect(function () {
    if (pdf) {
      pdf.getPage(page).then(function (p) {
        return drawPDF(p);
      });
    }
  }, [pdf, page, scale, rotate, canvasEl]); // draw a page of the pdf

  var drawPDF = function drawPDF(page) {
    // Because this page's rotation option overwrites pdf default rotation value,
    // calculating page rotation option value from pdf default and this component prop rotate.
    var rotation = rotate === 0 ? page.rotate : page.rotate + rotate;
    var dpRatio = 1;
    dpRatio = window.devicePixelRatio;
    var adjustedScale = scale * dpRatio;
    var viewport = page.getViewport({
      scale: adjustedScale,
      rotation: rotation
    });
    var canvas = canvasEl.current;

    if (!canvas) {
      return;
    }

    var canvasContext = canvas.getContext('2d');
    canvas.style.width = viewport.width / dpRatio + "px";
    canvas.style.height = viewport.height / dpRatio + "px";
    canvas.height = viewport.height;
    canvas.width = viewport.width;
    var renderContext = {
      canvasContext: canvasContext,
      viewport: viewport
    };
    page.render(renderContext);
  };

  var loading = useMemo(function () {
    return !pdf;
  }, [pdf]);
  var numPages = useMemo(function () {
    return pdf ? pdf._pdfInfo.numPages : null;
  }, [pdf]);
  return [loading, numPages];
};

export default Pdf;
export { usePdf };
//# sourceMappingURL=react-pdf.esm.js.map
